##  Execute Transformations in Bulk with the Transformations Explorer
If you need to run several transformations at once, such as for all transformations in your roadmap, use the transformations explorer. It provides a centralized view of all your transformation initiatives, making it easy to monitor progress, review details, and manage upcoming tasks.
Learn more about the transformations explorer in [Transformations Explorer](https://help.sap.com/docs/leanix/ea/transformations-explorer?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to use the transformations explorer to get visibility into all of your transformation activities. Use it to streamline planning and execution with features like scope-based filtering and bulk actions.").
To execute transformations for multiple initiatives at once, do the following:
  1. Go to More, and select Transformations Explorer.
  2. Filter by your initiatives and the status Ready to Execute.
  3. Choose Select All or select the transformations you want to execute.
  4. Choose Review and Execute > Execute Now.


Executing Multiple Transformations with the Transformations Explorer
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioa9eadba0f5334da496d607f45b54ceb2_LowRes.png)
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
